/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (C) 2025, STMicroelectronics - All Rights Reserved
 */

#ifndef __DT_BINDINGS_REGULATOR_ST_STM32MP15_REGULATOR_H
#define __DT_BINDINGS_REGULATOR_ST_STM32MP15_REGULATOR_H

/* SCMI voltage domain identifiers */

/* SOC Internal regulators */
#define VOLTD_SCMI_REG11		0
#define VOLTD_SCMI_REG18		1
#define VOLTD_SCMI_USB33		2

/* STPMIC1 regulators */
#define VOLTD_SCMI_STPMIC1_BUCK1	3
#define VOLTD_SCMI_STPMIC1_BUCK2	4
#define VOLTD_SCMI_STPMIC1_BUCK3	5
#define VOLTD_SCMI_STPMIC1_BUCK4	6
#define VOLTD_SCMI_STPMIC1_LDO1		7
#define VOLTD_SCMI_STPMIC1_LDO2		8
#define VOLTD_SCMI_STPMIC1_LDO3		9
#define VOLTD_SCMI_STPMIC1_LDO4		10
#define VOLTD_SCMI_STPMIC1_LDO5		11
#define VOLTD_SCMI_STPMIC1_LDO6		12
#define VOLTD_SCMI_STPMIC1_VREFDDR	13
#define VOLTD_SCMI_STPMIC1_BOOST	14
#define VOLTD_SCMI_STPMIC1_PWR_SW1	15
#define VOLTD_SCMI_STPMIC1_PWR_SW2	16
#define VOLTD_SCMI_VREFBUF		17

/* External regulators */
#define VOLTD_SCMI_REGU0		18
#define VOLTD_SCMI_REGU1		19
#define VOLTD_SCMI_REGU2		20
#define VOLTD_SCMI_REGU3		21
#define VOLTD_SCMI_REGU4		22

#endif /*__DT_BINDINGS_REGULATOR_ST_STM32MP15_REGULATOR_H */
