/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (C) 2023 SiFive
 */

#ifndef _ASM_X86_FPU_H
#define _ASM_X86_FPU_H

#include <asm/fpu/api.h>

#define kernel_fpu_available()	true

#endif /* ! _ASM_X86_FPU_H */
