/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (C) 2014, 2016 Antony Pavlov <antonynpavlov@gmail.com>
 */

#ifndef __DT_BINDINGS_ATH79_CLK_H
#define __DT_BINDINGS_ATH79_CLK_H

#define ATH79_CLK_CPU		0
#define ATH79_CLK_DDR		1
#define ATH79_CLK_AHB		2
#define ATH79_CLK_REF		3
#define ATH79_CLK_MDIO		4

#define ATH79_CLK_END		5

#endif /* __DT_BINDINGS_ATH79_CLK_H */
